[maemo-commits] [maemo-commits] r17469 - in projects/haf/trunk/libmatchbox2: . matchbox/core

From: subversion at stage.maemo.org subversion at stage.maemo.org
Date: Thu Feb 19 18:10:49 EET 2009
Author: kihamala
Date: 2009-02-19 18:10:49 +0200 (Thu, 19 Feb 2009)
New Revision: 17469

Modified:
   projects/haf/trunk/libmatchbox2/ChangeLog
   projects/haf/trunk/libmatchbox2/matchbox/core/mb-wm-client-base.c
Log:
revert the revert_to change..


Modified: projects/haf/trunk/libmatchbox2/ChangeLog
===================================================================
--- projects/haf/trunk/libmatchbox2/ChangeLog	2009-02-19 15:59:52 UTC (rev 17468)
+++ projects/haf/trunk/libmatchbox2/ChangeLog	2009-02-19 16:10:49 UTC (rev 17469)
@@ -1,11 +1,3 @@
-2009-02-19  Kimmo Hämäläinen  <kimmo.hamalainen at nokia.com>
-
-	* matchbox/core/mb-wm-client-base.c (mb_wm_client_base_display_sync,
-	mb_wm_client_base_focus): Use RevertToParent instead of
-	RevertToPointerRoot since we don't have pointer-based focus system
-	(in the sense that the user cannot see it, the user can still move
-	focus by pointer press).
-
 2009-02-16  Thomas Thurman  <thomas.thurman at collabora.co.uk>
 
 	* matchbox/core/mb-wm-client-window.c: initialise cookies

Modified: projects/haf/trunk/libmatchbox2/matchbox/core/mb-wm-client-base.c
===================================================================
--- projects/haf/trunk/libmatchbox2/matchbox/core/mb-wm-client-base.c	2009-02-19 15:59:52 UTC (rev 17468)
+++ projects/haf/trunk/libmatchbox2/matchbox/core/mb-wm-client-base.c	2009-02-19 16:10:49 UTC (rev 17469)
@@ -544,11 +544,11 @@
 	{
 	  /*
 	   * If we are the currently focused client,
 	   * we need to reset the focus to RevertToParent, since the
 	   * focus was lost during the implicit unmap.
 	   */
 	  XSetInputFocus (wm->xdpy, client->window->xwindow,
-			  RevertToParent, CurrentTime);
+			  RevertToPointerRoot, CurrentTime);
 
 	}
     }
@@ -784,7 +784,7 @@
 
   mb_wm_util_trap_x_errors ();
 
-  XSetInputFocus(wm->xdpy, xwin, RevertToParent, CurrentTime);
+  XSetInputFocus(wm->xdpy, xwin, RevertToPointerRoot, CurrentTime);
 
   XChangeProperty(wm->xdpy, wm->root_win->xwindow,
 		  wm->atoms[MBWM_ATOM_NET_ACTIVE_WINDOW],
@@ -544,11 +544,11 @@
 	  /*
 	   * If we are the currently focused client,
-	   * we need to reset the focus to RevertToParent, since the
+	   * we need to reset the focus to RevertToPointerRoot, since the
 	   * focus was lost during the implicit unmap.
 	   */


More information about the maemo-commits mailing list